========================
Team and repository tags
========================

.. image:: http://governance.openstack.org/badges/futurist.svg
    :target: http://governance.openstack.org/reference/tags/index.html

.. Change things from this point on

========
Futurist
========

.. image:: https://img.shields.io/pypi/v/futurist.svg
    :target: https://pypi.python.org/pypi/futurist/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/futurist.svg
    :target: https://pypi.python.org/pypi/futurist/
    :alt: Downloads

Code from the future, delivered to you in the **now**. The goal of this library
would be to provide a well documented futures classes/utilities/additions that
allows for providing a level of transparency in how asynchronous work gets
executed. This library currently adds statistics gathering, an eventlet
executor, a synchronous executor etc.

* Free software: Apache license
* Documentation: https://docs.openstack.org/futurist/latest/
* Source: https://git.openstack.org/cgit/openstack/futurist
* Bugs: https://bugs.launchpad.net/futurist
